/*
	1369_cons.h Rev.1.00 (VDSP++ 4.5)
	
	Funkcje obsugi wyswietlacza LCD 20x4
	oraz klawiatury 12 kl. systemu ALS-G3-1369

	(c) ALFINE P.E.P. 03.2008
*/


#include "sys_def.h"

//Funkcja inicjalizacji moduu LCD
extern void init_LCD( void );

//Funkcja kasowania zawartosci pamici DDRAM moduu LCD (CURSOR HOME)
extern void clr_LCD( void );

//Funkcja formatowania i wyprowadzania na ekran LCD
//lancucha znakw (string) lub liczby typu floating_point
extern void lprintf_LCD( unsigned startpos, const char *control, ... );
//argumenty:
//' startpos': pozycja startowa acucha w zakresie <0,39> oraz <64,103>
//'control': '%s' - acuch znakw, '%fx.y' - liczba fp na 'x' pozycjach, w tym 'y' pozycji po przecinku 
//argument nr 3: zmienna wyprowadzana na ekran


//Funkcja opnienia o 'wt_pc' [processor_core_cycle]
void wait_pc( unsigned wt_pc );


//Funkcja opnienia o 'wt_ms' [ms]
void wait_ms( unsigned wt_ms );


//--- read_kbd ---
//Funkcja odczytu klawiatury 10 kl.; zwraca wynik typu 'unsigned int';
//   
//Funkcja zwraca stan klawiatury po zwolnieniu i naciniciu klawisza !
//
//Zwracane wartosci:
//K1 -> 1 (bit 0)
//K2 -> 2 (bit 1)
//K3 -> 4 (bit 2)
//K4 -> 8 ...
//K5 -> 16
//K6 -> 32
//K7 -> 64
//K8 -> 128
//K9 -> 256
//K10 -> 512
//ALT -> 1024; stan przycisku ALT podawany jest rwnolegle z pozostaymi
//CTRL -> 2048; stan przycisku CTRL podawany jest rwnolegle z pozostaymi

#define K1		1  //code of K1 key
#define K2		2  //code of K2 key
#define K3		4  //...
#define K4		8
#define K5		16
#define K6		32
#define K7		64
#define K8		128
#define K9		256
#define K10		512
#define ALT		1024
#define CTRL	2048


//Locally utilized functions
unsigned int get_kbd_state(void);  //returns KBD buffer state

#define KL	0x2000  //select low key row
#define KH	0x1000  //select high key row

unsigned int read_kbd(void)
{
  static unsigned int buf, buf_;

  do
  {
    buf = get_kbd_state();
  }
  while(buf!=0);  //wait for key releasing (no ALT or CTRL !)

  
  do
  {
    buf = get_kbd_state();
  }
  while(buf==0);  //wait for key releasing (no ALT or CTRL !)

  
  while(buf!=buf_)  //checking kbd state twice !
  {
    buf = get_kbd_state();  //check state
    wait_ms(10);  //delay - for debuncing
    buf_ = get_kbd_state();  //check state again
  }
  
  if(buf&KL)  //formatting reslut
  {
    buf = ((~buf<<5)&0xc00)|(~buf&0x1f);
    return(buf);
  }  
  
  if(buf&KH)  //formatting reslut
  {
    buf = (~buf<<5)&0xfe0;
    return(buf);
  }
  return(0);
}


unsigned int get_kbd_state(void)
{
  static unsigned buf, buf_;
  
  *USRCONS = KL;
  buf = *USRCONS;
  buf = buf&0x7f;  //select active key buffer lines
  buf_ = buf&0x1f;  //non special keys only !
  if(buf_^0x1f)
    return(buf | KL);
      
  *USRCONS = KH;
  buf = *USRCONS;
  buf = buf&0x7f;  //select active key buffer lines
  buf_ = buf&0x1f;  //non special keys only !
  if(buf_^0x1f)
    return(buf | KH);
    
  return(0);
}
//------------------------------------------------



void wait_pc( unsigned  wt_pc )
{
  while ( wt_pc-- > 0 );
}


void  wait_ms( unsigned wt_ms )
{
  do wait_pc( 40000 ); //CORE_CLK = 400 [MHz]
    while( wt_ms-- );
}
