/*
	sys_serv.h (Rev. 1.0)

	ALS-G3-1369
	
	System Utility Functions Header File
	
	ALFINE P.E.P., 03.2008
*/


//Predefined 'structure' type object
//- for DAC outgoing data storage
//!!! Declared variable Must Be located in DM !!!
typedef struct
{
  int Ch_A;  //channel A
  int Ch_B;  //channel B
  int Ch_C;  //...
  int Ch_D;
}DAC_Util;


//Predefined 'structure' type object
//- for ADC incoming data storage
//!!! Declared variable Must Be located in DM !!!
typedef struct
{
  int Ch_1;  //ADC chan. No 1
  int Ch_2;  //ADC chan. No 2
  int Ch_3;  //...
  int Ch_4;
  int Ch_5;
  int Ch_6;
}ADC_Util;


//!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
//System Initilization Function - OBLIGATORY !!!
//
//Function sets:
//- Core Clock Frequency at 24 x 16/1 = 384 MHz
//- EPCTL to 16 bit EXTERNAL DATA LANE
//- EPCTL to use all ext. banks in AMI mode and core access
//
extern int PLL_SDCLK_Init(void);
//Arguments: none; returns: Core_Clock_Frequency
//!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!


//Function enables inverter interface
//
extern void INV_ENA(void);


//Function disables inverter interface
//
extern void INV_DIS(void);


//Function resets and activates own inverter control block
//
extern void INV_START(void);
//Arguments: none; returns: nothing


//Function REFRESHES hardware WATCHDOG TIMER
//that enables inverter control buffer (PWM & FLAGS)
//
extern void WDG_RFSH(void);
//Arguments: none; returns: nothing


//Function INITIALIZES PWM Gneretor - PWM Group 0;
//Groups:1/2/3 works in FLAGS Mode
//
//Parameters of PWM:
//Edge Aligned / Paired Mode / Single Update
//Active Low / PWM0/AL(->D16) channel is enabled
//*** PWM Group 0 interrupt is configured and internally enabled ***
//
extern void PWM_Init(unsigned period, unsigned dead_time);
//Arguments: processor_number, PWM period
//Returns: nothing


//Function CHANGES PWM duty cycle of PWM0/PWM1(A-channel)
//
extern void PWM_Duty(int duty_reg_A, int duty_reg_B, int duty_reg_C);
//Arguments: PWM_duty_cycle_regs - A0, B0, A1
//Returns: nothing


//Function PUTS data to DAC
//Data should be in range <-32768, 32767>; MOST 14 bits are valid !
extern void	DAC_Data_Out(DAC_Util *data);
//Arguments: adress_of_structure_with_DAC_data
//Returns: nothing


//Function GETS data from 6-channel ADC No 1
//Data is in range <-2^15, 2^15-1>
extern void ADC1_Data_In(unsigned const ADC_config, ADC_Util *data);
//Arguments: ADC_configuration, adres_of_structure_with_DAC_data
//Returns: nothing


//Function GETS data from 6-channel ADC No 2
//Data is in range <-2^15, 2^15-1>
extern void ADC2_Data_In(unsigned const ADC_config, ADC_Util *data);
//Arguments: ADC_configuration, adres_of_structure_with_DAC_data
//Returns: nothing


//Function CONFIGURES PCG_A
//and ENABLES Frame Sync signal generation
//at freq. sets by 'divisor'
//Frame signal is routed to DAI_P15 PIN and DAI_P14 PIN
//so BOTH ADCs are initiated simultaneously !!!
//PCG input clock: 24,000 MHz
extern void Set_PCG(unsigned divisor);
//Arguments: clock_divisor
//Returns: nothing
